@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2022-01-26 17:16:34
+@LastEditTime: 2022-03-08 17:38:37
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -52,12 +52,13 @@ class LoginHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-
+        union_id = ""
         if pt == "wx" and code:
             invoke_result_data = WeChatHelper.code2_session(code, app_id=config.get_value("app_id"), app_secret=config.get_value("app_secret"))
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
             open_id =  invoke_result_data.data["openid"]
+            union_id =  invoke_result_data.data.get("unionid","")
         elif pt == "tt" and code:
             invoke_result_data = TikTokHelper.code2_session(code, anonymous_code, app_id=config.get_value("app_id"), app_secret=config.get_value("app_secret"))
             if invoke_result_data.success == False:
@@ -65,7 +66,7 @@ class LoginHandler(ClientBaseHandler):
             open_id = invoke_result_data.data["openid"]
 
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar)
+        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data.data["user_nick"] = self.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
@@ -158,6 +159,31 @@ class CheckIsMemberHandler(ClientBaseHandler):
         return self.response_json_success(top_base_model.check_is_member(mix_nick,"", access_token, app_key, app_secret, is_log))
 
 
+class GetCrmIntegralHandler(ClientBaseHandler):
+    """
+    :description: 获取店铺会员积分
+    """
+    @filter_check_params()
+    def get_async(self):
+        """
+        :description: 获取店铺会员积分
+        :return: 店铺会员积分
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_source_app_id()
+        user_nick = self.get_param("user_nick")
+        app_base_model = AppBaseModel(context=self)
+        app_info_dict = app_base_model.get_app_info_dict(app_id)
+        if not app_info_dict:
+            return self.response_json_error("error", "小程序不存在")
+        top_base_model = TopBaseModel(context=self)
+        invoke_result_data = top_base_model.get_crm_point_available(user_nick, app_info_dict["access_token"])
+        if invoke_result_data.success == False:
+            return self.reponse_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        shop_member_integral = invoke_result_data.data
+        return self.reponse_json_success(shop_member_integral)
+
+
 class ApplyBlackUnbindHandler(ClientBaseHandler):
     """
     :description: 提交黑名单解封申请
@@ -273,6 +299,31 @@ class GetCouponPrizeHandler(ClientBaseHandler):
             return self.response_json_error("error", f"领取失败:{result}")
 
 
+class GetUserAssetHandler(ClientBaseHandler):
+    """
+    :description: 获取单条用户资产
+    """
+    @filter_check_params("act_id,tb_user_id,asset_type")
+    def get_async(self):
+        """
+        :description: 获取单条用户资产
+        :param act_id：活动标识
+        :param tb_user_id：用户标识
+        :param asset_type：资产类型(1-次数2-积分3-价格档位)
+        :param asset_object_id：资产对象标识
+        :return list
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_source_app_id()
+        act_id = int(self.get_param("act_id", 0))
+        user_id = self.get_user_id()
+        asset_type = int(self.get_param("asset_type", 0))
+        asset_object_id = self.get_param("asset_object_id", "")
+
+        asset_base_model = AssetBaseModel(context=self)
+        return self.response_json_success(asset_base_model.get_user_asset(app_id, act_id, user_id, asset_type, asset_object_id))
+
+
 class UserAssetListHandler(ClientBaseHandler):
     """
     :description: 获取用户资产列表
