@@ -20,7 +20,7 @@ from seven_framework.redis import *
 from seven_framework.web_tornado.base_handler.base_api_handler import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.libs.customize.cryptography_helper import *
-from seven_cloudapp_frame.libs.customize.string_helper import *
+from seven_cloudapp_frame.libs.customize.attack_helper import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.user_base_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
@@ -63,6 +63,11 @@ class FrameBaseHandler(BaseApiHandler):
             # 标记日志请求关联
             dict_param = self.get_http_log_extra_dict()
             self._build_http_log(dict_param)
+            # 记录请求参数明文
+            if config.get_value("log_plain",True) == True and self.check_api_is_encrypt() == True:
+                self.logging_link_info(f"plain_request_params:{self.json_dumps(self.request_params)}")
+            
+            
         except Exception as ex:
             if not hasattr(self, "request_code"):
                 self.request_code = UUIDHelper.get_uuid()
@@ -110,11 +115,11 @@ class FrameBaseHandler(BaseApiHandler):
             param_ret = self.get_argument(param_name, default, strip=strip)
         if param_ret == "" or param_ret == "undefined":
             param_ret = default
-        param_ret = StringHelper.filter_routine_key(param_ret)
+        param_ret = AttackHelper.filter_routine_key(param_ret)
         if filter_sql == True:
-            param_ret = StringHelper.filter_sql(param_ret)
+            param_ret = AttackHelper.filter_sql(param_ret)
         if filter_special_key == True:
-            param_ret = StringHelper.filter_special_key(param_ret)
+            param_ret = AttackHelper.filter_special_key(param_ret)
         return param_ret
 
     def get_param_int(self, param_name, default=0, strip=True, filter_sql=False, filter_special_key=False):
@@ -134,6 +139,19 @@ class FrameBaseHandler(BaseApiHandler):
             param = default
         return param
 
+    def check_api_is_encrypt(self):
+        """
+        :Description: 校验是否加密
+        :last_editors: HuangJianYi
+        """
+        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密，2-md5加密
+        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密，2-md5加密
+        is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
+        if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+            return True
+        else:
+            return False
+
     def _convert_request_params(self):
         """
         :Description: 转换请求参数 post请求：Content-type必须为application/json，前端必须对对象进行序列化转成json字符串，不能直接传对象,否则无法接收参数,存在特殊字符的参数必须进行url编码，否则+会被变成空值
@@ -141,10 +159,7 @@ class FrameBaseHandler(BaseApiHandler):
         """
         invoke_result_data = InvokeResultData()
         self.request_params = {}
-        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密，2-md5加密
-        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密，2-md5加密
-        is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
-        if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+        if self.check_api_is_encrypt() == True:
             encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
             if hasattr(self, "encrypt_key"):
                 encrypt_key = self.encrypt_key
@@ -189,6 +204,7 @@ class FrameBaseHandler(BaseApiHandler):
                         invoke_result_data.error_code = "error"
                         invoke_result_data.error_message = "参数解析错误"
                         return invoke_result_data
+
         else:
             if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
                 try:
@@ -231,9 +247,7 @@ class FrameBaseHandler(BaseApiHandler):
         if is_encrypt == False:
             template_value['data'] = data
         else:
-            client_encrypt_type = config.get_value("client_encrypt_type", 0)
-            server_encrypt_type = config.get_value("server_encrypt_type", 0)
-            if ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+            if self.check_api_is_encrypt() == True:
                 dv = SevenHelper.get_random(16)
                 encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
                 if self.get_argument("app_id", "", strip=True):
@@ -246,6 +260,8 @@ class FrameBaseHandler(BaseApiHandler):
                 iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
                 template_value['data'] = CryptographyHelper.aes_encrypt(self.json_dumps(data), password, iv)
                 template_value['dv'] = dv
+                if config.get_value("log_plain",True) == True:
+                    self.logging_link_info(f"plain_response_data:{self.json_dumps(data)}")
             else:
                 template_value['data'] = data
         template_value['error_code'] = "error" if not error_code and success == False else error_code
@@ -259,7 +275,7 @@ class FrameBaseHandler(BaseApiHandler):
         log_extra_dict["is_success"] = 1
         if success == False:
             log_extra_dict["is_success"] = 0
-
+        
         self.http_reponse(self.json_dumps(rep_dic), log_extra_dict)
 
     def response_json_success(self, data=None):
@@ -583,7 +599,7 @@ class FrameBaseHandler(BaseApiHandler):
         is_filter_attack = config.get_value("is_filter_attack", False)
         if is_filter_attack == True and self.request_params:
             for key in self.request_params.keys():
-                if StringHelper.is_contain_sql(self.request_params[key]) or StringHelper.is_attack(self.request_params[key]):
+                if AttackHelper.is_contain_sql(self.request_params[key]) or AttackHelper.is_attack(self.request_params[key]):
                     result = True, f"参数{key}:值不合法"
                     break
         return result
@@ -652,6 +668,10 @@ class ClientBaseHandler(FrameBaseHandler):
             dict_param = self.get_http_log_extra_dict()
             self._build_http_log(dict_param)
 
+            # 记录请求参数明文
+            if config.get_value("log_plain",True) == True and self.check_api_is_encrypt() == True:
+                self.logging_link_info(f"plain_request_params:{self.json_dumps(self.request_params)}")
+
             # 获取设备信息
             self.device_info_dict = self.get_device_info_dict()
 
