@@ -72,6 +72,8 @@ class IpInfoListHandler(ClientBaseHandler):
         :description: 获取ip列表
         :param app_id：应用标识
         :param act_id：活动标识
+        :param is_del: 是否回收站1是0否
+        :param is_release: 是否发布1是0否
         :param page_index：页索引
         :param page_size：页大小
         :return: list
@@ -79,6 +81,8 @@ class IpInfoListHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
+        is_del = int(self.get_param("is_del", 0))
+        is_release = int(self.get_param("is_release", -1))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
@@ -91,7 +95,7 @@ class IpInfoListHandler(ClientBaseHandler):
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc"
-        page_list, total = IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, field, condition, params, order_by, is_cache=False)
+        page_list, total = IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, is_del, is_release, field, condition, params, order_by, is_cache=False)
         ref_params = {}
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
