@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-01-13 14:48:28
+@LastEditTime: 2022-02-25 14:10:00
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -25,23 +25,22 @@ class ActBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def _delete_act_info_dependency_key(self,app_id,act_id):
+    def _delete_act_info_dependency_key(self,app_id,act_id,delay_delete_time=0.1):
         """
         :description: 删除活动信息依赖建
         :param app_id: 应用标识
         :param act_id: 活动标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        try:
-            redis_init = SevenHelper.redis_init()
-            if act_id:
-                redis_init.delete(f"act_info:actid_{act_id}")
-            if app_id:
-                redis_init.delete(f"act_info_list:appid_{app_id}")
-        except Exception as ex:
-            pass
-        
+        dependency_key_list = []
+        if act_id:
+            dependency_key_list.append(f"act_info:actid_{act_id}") 
+        if app_id:
+            dependency_key_list.append(f"act_info_list:appid_{app_id}")
+        ActInfoModel().delete_dependency_key(dependency_key_list, delay_delete_time)
+
     def get_act_info_dict(self,act_id,is_cache=True,is_filter=True):
         """
         :description: 获取活动信息
@@ -86,7 +85,7 @@ class ActBaseModel():
         if is_cache:
             page_list, total = ActInfoModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params,dependency_key=f"act_info_list:appid_{app_id}")
         else:
-            page_list, total = ActInfoModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params)    
+            page_list, total = ActInfoModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params)
         for page in page_list:
             page["share_desc_json"] = SevenHelper.json_loads(page["share_desc_json"]) if page["share_desc_json"] else {}
             page["rule_desc_json"] = SevenHelper.json_loads(page["rule_desc_json"]) if page["rule_desc_json"] else []
@@ -250,13 +249,13 @@ class ActBaseModel():
         if s3 !=None:
             act_info.s3 = s3
         if s4 !=None:
-             act_info.s4 = s4
+            act_info.s4 = s4
         if s5 !=None:
-             act_info.s5 = s5
+            act_info.s5 = s5
         if d1 !=None:
-             act_info.d1 = d1
+            act_info.d1 = d1
         if d2 !=None:
-             act_info.d2 = d2
+            act_info.d2 = d2
         act_info.modify_date = now_datetime
         act_info_model.update_entity(act_info,exclude_field_list="finish_menu_config_json,is_finish,task_asset_type_json,is_launch")
         result = {}
@@ -265,7 +264,7 @@ class ActBaseModel():
         invoke_result_data.data = result
         self._delete_act_info_dependency_key(app_id,act_info.id)
         return invoke_result_data
-    
+
     def update_act_info_status(self,app_id,act_id,is_del):
         """
         :description: 删除或者还原活动
@@ -362,5 +361,3 @@ class ActBaseModel():
             app_info_model = AppInfoModel(context=self.context)
             app_info_model.update_table("is_setting=1", "app_id=%s", [app_id])
         return invoke_result_data
-  
-    
\ No newline at end of file
