@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-01-21 21:28:11
+@LastEditTime: 2022-03-09 09:23:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -167,8 +167,9 @@ class AppBaseModel():
                     base_info["client_ver"] = version_info.version_number
         #配置文件指定账号升级
         if user_nick:
-            if user_nick == config.get_value("test_user_nick"):
-                base_info["client_ver"] = config.get_value("test_client_ver")
+            test_config = config.get_value("test_config",{})
+            if user_nick == test_config.get("user_nick",""):
+                base_info["client_ver"] = test_config.get("client_ver","")
         data["base_info"] = base_info
         invoke_result_data.data =data
         return invoke_result_data
@@ -204,19 +205,23 @@ class AppBaseModel():
         if invoke_result_data.success == False:
             return invoke_result_data
         dead_date = invoke_result_data.data
+        project_code = top_base_model.get_project_code(store_user_nick,access_token,app_key, app_secret)
         now_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(TimeHelper.get_now_format_time('%Y-%m-%d 00:00:00'), '%Y-%m-%d %H:%M:%S'))
         login_log = TaoLoginLogModel(context=self.context).get_entity("open_id=%s", order_by="id desc", params=open_id)
         if app_info:
             if dead_date != "expire":
                 app_info.expiration_date = dead_date
+            if project_code != "":
+                app_info.project_code = project_code
             invoke_result_data = top_base_model.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
             if invoke_result_data.success == True:
                 app_info.access_token = access_token
-            app_info_model.update_entity(app_info,"expiration_date,access_token")
+            app_info_model.update_entity(app_info,"expiration_date,project_code,access_token")
             app_info_model.delete_dependency_key(f"app_info:appid_{app_info.app_id}")
 
             app_info.user_nick = user_nick
             app_info.dead_date = dead_date
+            app_info.project_code = project_code
             if app_info.dead_date != "expire":
                 dead_date_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(app_info.dead_date, '%Y-%m-%d %H:%M:%S'))
                 app_info.surplus_day = int(int(abs(dead_date_timestamp - now_timestamp)) / 24 / 3600)
@@ -231,6 +236,7 @@ class AppBaseModel():
             app_info.template_ver = base_info["client_ver"]
             app_info.user_nick = user_nick
             app_info.dead_date = dead_date
+            app_info.project_code = project_code
             if app_info.dead_date != "expire":
                 dead_date_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(app_info.dead_date, '%Y-%m-%d %H:%M:%S'))
                 app_info.surplus_day = int(int(abs(dead_date_timestamp - now_timestamp)) / 24 / 3600)
