@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2022-02-25 09:44:51
+@LastEditTime: 2022-02-28 11:52:22
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -24,20 +24,16 @@ class AssetBaseModel():
         self.logging_link_info = logging_info
 
 
-    def _delete_asset_dependency_key(self,act_id,user_id):
+    def _delete_asset_dependency_key(self, act_id, user_id, delay_delete_time=0.1):
         """
         :description: 删除资产依赖建
         :param act_id: 活动标识
         :param user_id: 用户标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        try:
-            redis_init = SevenHelper.redis_init()
-            if act_id and user_id:
-                redis_init.delete(f"asset_log_list:actid_{act_id}_userid_{user_id}")
-        except Exception as ex:
-            pass
+        AssetLogModel().delete_dependency_key(f"asset_log_list:actid_{act_id}_userid_{user_id}", delay_delete_time)
 
     def _add_onlyid_warn_stat(self,handler_name):
         """
@@ -163,11 +159,11 @@ class AssetBaseModel():
                 #添加唯一标识预警拦截计数,用于控制台跑数据进行并发预警
                 self._add_onlyid_warn_stat(handler_name)
                 return invoke_result_data
-        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
+        sub_table_config = config.get_value("sub_table_config",{})
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        user_asset_model = UserAssetModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
-        asset_log_model = AssetLogModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
-        asset_only_model = AssetOnlyModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
+        user_asset_model = UserAssetModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("user_asset_num", 0)), context=self.context)
+        asset_log_model = AssetLogModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("asset_log_num", 0)), context=self.context)
+        asset_only_model = AssetOnlyModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("asset_only_num", 0)), context=self.context)
 
         acquire_lock_name = f"userasset:{user_asset_id_md5}"
         acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
@@ -267,7 +263,7 @@ class AssetBaseModel():
             asset_log_model.add_entity(asset_log)
 
             result,message = db_transaction.commit_transaction(return_detail_tuple=True)
-            if not result:
+            if result == False:
                 if only_id:
                     #添加唯一标识预警拦截计数,用于控制台跑数据进行并发预警
                     self._add_onlyid_warn_stat(handler_name)
@@ -280,27 +276,32 @@ class AssetBaseModel():
                 invoke_result_data.error_code = "fail"
                 invoke_result_data.error_message = "系统繁忙,请稍后再试"
                 return invoke_result_data
+            try:
+                if only_id:
+                    redis_init.hset(only_cache_key, only_id, 1)
+                    redis_init.expire(only_cache_key, 24 * 3600)
+                self._delete_asset_dependency_key(act_id,user_id)
 
-            if only_id:
-                redis_init.hset(only_cache_key, only_id, 1)
-                redis_init.expire(only_cache_key, 24 * 3600)
-            self._delete_asset_dependency_key(act_id,user_id)
-
-            asset_queue = {}
-            asset_queue["app_id"] = app_id
-            asset_queue["act_id"] = act_id
-            asset_queue["open_id"] = open_id
-            asset_queue["user_nick"] = user_nick
-            asset_queue["user_id"] = user_id
-            asset_queue["asset_type"] = asset_type
-            asset_queue["asset_object_id"] = asset_object_id
-            asset_queue["now_value"] = user_asset.asset_value
-            asset_queue["operate_value"] = asset_value
-            asset_queue["history_asset_value"] = history_asset_value
-            asset_queue["now_day_int"] = now_day_int
-            asset_queue["create_date"] = now_datetime
-            redis_init.rpush(f"asset_queue_list:{str(user_id % 10)}",SevenHelper.json_dumps(asset_queue))
-
+                asset_queue = {}
+                asset_queue["app_id"] = app_id
+                asset_queue["act_id"] = act_id
+                asset_queue["open_id"] = open_id
+                asset_queue["user_nick"] = user_nick
+                asset_queue["user_id"] = user_id
+                asset_queue["asset_type"] = asset_type
+                asset_queue["asset_object_id"] = asset_object_id
+                asset_queue["now_value"] = user_asset.asset_value
+                asset_queue["operate_value"] = asset_value
+                asset_queue["history_asset_value"] = history_asset_value
+                asset_queue["now_day_int"] = now_day_int
+                asset_queue["create_date"] = now_datetime
+                redis_init.rpush(f"asset_queue_list:{str(user_id % 10)}",SevenHelper.json_dumps(asset_queue))
+            except Exception as ex:
+                if self.context:
+                    self.context.logging_link_error("【资产队列】" + traceback.format_exc())
+                elif self.logging_link_error:
+                    self.logging_link_error("【资产队列】" + traceback.format_exc())
+            
             invoke_result_data.data = {"user_asset":user_asset.__dict__}
 
         except Exception as ex:
@@ -343,8 +344,8 @@ class AssetBaseModel():
             else:
                 condition += " AND user_id=%s"
                 params.append(user_ids)
-        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
-        user_asset_model = UserAssetModel(sub_table=sub_table, context=self.context)
+        sub_table_config = config.get_value("sub_table_config",{})
+        user_asset_model = UserAssetModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("user_asset_num", 0)), context=self.context)
         user_asset_dict_list = user_asset_model.get_dict_list(condition, params=params)
         if len(user_asset_dict_list) > 0:
             for user_asset_dict in user_asset_dict_list:
@@ -368,8 +369,8 @@ class AssetBaseModel():
         """
         if not act_id or not user_id or not asset_type:
             return None
-        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
-        user_asset_model = UserAssetModel(sub_table=sub_table, context=self.context)
+        sub_table_config = config.get_value("sub_table_config", {})
+        user_asset_model = UserAssetModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("user_asset_num", 0)), context=self.context)
         user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
         user_asset_dict = user_asset_model.get_dict("id_md5=%s", limit="1", params=[user_asset_id_md5])
         if user_asset_dict:
@@ -441,8 +442,8 @@ class AssetBaseModel():
             else:
                 condition += " AND source_object_id=%s"
                 params.append(source_object_id)
-        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
-        asset_log_model = AssetLogModel(sub_table=sub_table, context=self.context)
+        sub_table_config = config.get_value("sub_table_config", {})
+        asset_log_model = AssetLogModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("asset_log_num", 0)), context=self.context)
         if is_cache:
             page_list, total = asset_log_model.get_cache_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params,dependency_key=f"asset_log_list:actid_{act_id}_userid_{user_id}")
         else:
