@@ -22,6 +22,7 @@ class CacheModel(BaseModel):
         :param sub_table: 分表标识
         :last_editors: HuangJianYi
         """
+        self.cache_prefix = "data_cache"
         super(CacheModel,self).__init__(model_class, sub_table)
 
     def __get_dependency_key(self, dependency_key=''):
@@ -32,8 +33,8 @@ class CacheModel(BaseModel):
         :last_editors: HuangJianYi
         """
         if not dependency_key:
-            dependency_key = "dependency_" + self.table_name.lower()
-        return dependency_key
+            dependency_key = self.table_name.lower()
+        return self.cache_prefix + ":" + "dependency_" + dependency_key
 
     def __get_cache_key(self, field, where='', group_by='', order_by='', limit='', params=None):
         """
@@ -65,7 +66,7 @@ class CacheModel(BaseModel):
         :return: 依赖缓存key
         :last_editors: HuangJianYi
         """
-        return CryptoHelper.md5_encrypt(dependency_key+cache_key)
+        return self.cache_prefix + ":" + CryptoHelper.md5_encrypt(dependency_key+cache_key)
 
     def __get_dependency_cache(self, dependency_key, cache_key):
         """
@@ -106,7 +107,7 @@ class CacheModel(BaseModel):
 
     def __set_dependency_cache(self, dependency_key, cache_key,value, cache_expire):
         """
-        :Description: 获取依赖缓存值
+        :Description: 设置依赖缓存值
         :param dependency_key: 依赖键
         :param cache_key: 缓存key
         :param cache_expire: 缓存时间（单位秒）
@@ -146,18 +147,24 @@ class CacheModel(BaseModel):
         :last_editors: HuangJianYi
         """
         count = 0
-        while count <= 2:
+        while count < 2:
             count += 1
             try:
+                success_count = 0
                 redis_init = self.__redis_init()
                 if delay_delete_time > 0:
                     time.sleep(delay_delete_time)
                 if isinstance(dependency_key,list):
                     for key in dependency_key:
-                        redis_init.delete(self.__get_dependency_key(key))
+                        is_del = redis_init.delete(self.__get_dependency_key(key))
+                        if is_del == 1:
+                            success_count += 1
+                    if success_count == len(dependency_key):
+                        break
                 else:
-                    redis_init.delete(self.__get_dependency_key(dependency_key))
-                break
+                    success_count = redis_init.delete(self.__get_dependency_key(dependency_key))
+                    if success_count == 1:
+                        break
             except:
                 print(traceback.print_exc())
                 pass
@@ -187,7 +194,7 @@ class CacheModel(BaseModel):
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
 
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "entitylist_" + self.table_name + "_" + self.__get_cache_key('*',where,group_by,order_by,limit,params)
+        cache_key = "entitylist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
         list_row = self.__get_dependency_cache(dependency_key,cache_key)
         if list_row and config.get_value("is_redis_cache",True) == True:
             if list_row == 'null':
