@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-02-10 11:29:41
+@LastEditTime: 2022-02-28 13:46:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -53,28 +53,18 @@ class StatConsoleModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        stat_queue_model = StatQueueModel(sub_table=sub_table, db_transaction=db_transaction)
-        del_stat_queue_sub_table = sub_table + "_del" if sub_table else "del"
-        del_stat_queue_model = StatQueueModel(sub_table=del_stat_queue_sub_table, db_transaction=db_transaction)
-        stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
-        stat_report_model = StatReportModel(sub_table=sub_table,db_transaction=db_transaction)
-        stat_orm_model = StatOrmModel()
-        instance_date = TimeHelper.get_now_format_time()
         print(f"{TimeHelper.get_now_format_time()} 统计队列{mod_value}启动")
 
         while True:
             try:
                 time.sleep(0.1)
-                if abs(TimeHelper.difference_hours(instance_date, TimeHelper.get_now_format_time())) >= 2:
-                    db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-                    stat_queue_model = StatQueueModel(sub_table=sub_table, db_transaction=db_transaction)
-                    del_stat_queue_sub_table = sub_table + "_del" if sub_table else "del"
-                    del_stat_queue_model = StatQueueModel(sub_table=del_stat_queue_sub_table, db_transaction=db_transaction)
-                    stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
-                    stat_report_model = StatReportModel(sub_table=sub_table,db_transaction=db_transaction)
-                    stat_orm_model = StatOrmModel()
-                    instance_date = TimeHelper.get_now_format_time()
+                db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+                stat_queue_model = StatQueueModel(sub_table=sub_table, db_transaction=db_transaction)
+                del_stat_queue_sub_table = sub_table + "_del" if sub_table else "del"
+                del_stat_queue_model = StatQueueModel(sub_table=del_stat_queue_sub_table, db_transaction=db_transaction)
+                stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
+                stat_report_model = StatReportModel(sub_table=sub_table,db_transaction=db_transaction)
+                stat_orm_model = StatOrmModel()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     stat_queue_list = stat_queue_model.get_list(f"process_count<10 and '{now_date}'>process_date", order_by="process_date asc", limit="100")
@@ -165,28 +155,22 @@ class StatConsoleModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        stat_orm_model = StatOrmModel()
-        instance_date = TimeHelper.get_now_format_time()
         print(f"{TimeHelper.get_now_format_time()} 统计队列{mod_value}启动")
 
         while True:
             try:
                 time.sleep(0.1)
-                if abs(TimeHelper.difference_hours(instance_date, TimeHelper.get_now_format_time())) >= 2:
-                    db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-                    stat_orm_model = StatOrmModel()
-                    instance_date = TimeHelper.get_now_format_time()
+                db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+                stat_orm_model = StatOrmModel()
                 stat_queue_json = SevenHelper.redis_init().lpop(f"stat_queue_list:{mod_value}")
                 if not stat_queue_json:
                     time.sleep(1)
                     continue
                 try:
                     stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
-                    sub_table = SevenHelper.get_sub_table(stat_queue_dict["act_id"], config.get_value("stat_sub_table_count", 0))
-                    stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
-                    stat_report_model = StatReportModel(sub_table=sub_table,db_transaction=db_transaction)
-
+                    sub_table_config = config.get_value("sub_table_config", {})
+                    stat_log_model = StatLogModel(sub_table=SevenHelper.get_sub_table(stat_queue_dict["act_id"], sub_table_config.get("stat_log_num", 0)), db_transaction=db_transaction)
+                    stat_report_model = StatReportModel(sub_table=SevenHelper.get_sub_table(stat_queue_dict["act_id"], sub_table_config.get("stat_report_num", 0)), db_transaction=db_transaction)
                     stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"]])
                     if not stat_orm:
                         continue
