@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-05 10:54:36
-@LastEditTime: 2022-01-13 14:52:49
+@LastEditTime: 2022-02-25 14:14:53
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -22,23 +22,23 @@ class ModuleBaseModel():
         self.logging_link_info = logging_info
 
 
-    def _delete_act_module_dependency_key(self,act_id,module_id):
-            """
-            :description: 删除活动模块依赖建
-            :param act_id: 活动标识
-            :param module_id: 活动模块标识
-            :return: 
-            :last_editors: HuangJianYi
-            """
-            try:
-                redis_init = SevenHelper.redis_init()
-                if module_id:
-                    redis_init.delete(f"act_module:moduleid_{module_id}")
-                if act_id:
-                    redis_init.delete(f"act_module_list:actid_{act_id}")
-            except Exception as ex:
-                pass
+    def _delete_act_module_dependency_key(self, act_id, module_id, delay_delete_time=0.1):
+        """
+        :description: 删除活动模块依赖建
+        :param act_id: 活动标识
+        :param module_id: 活动模块标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        dependency_key_list = []
+        if module_id:
+            dependency_key_list.append(f"act_module:moduleid_{module_id}")
+        if act_id:
+            dependency_key_list.append(f"act_module_list:actid_{act_id}")
+        ActModuleModel().delete_dependency_key(dependency_key_list, delay_delete_time)
         
+
     def get_act_module_dict(self,module_id,is_cache=True,is_filter=True):
         """
         :description: 获取活动模块
@@ -97,7 +97,7 @@ class ModuleBaseModel():
         if is_cache:
             page_list, total = ActModuleModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=f"act_module_list:actid_{act_id}")
         else:
-            page_list, total = ActModuleModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)    
+            page_list, total = ActModuleModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)
         return page_list, total
 
     def save_act_module(self,app_id,act_id,module_id,module_name,module_sub_name,start_date,end_date,module_pic,module_desc,price,price_gear_id,ip_id,join_ways,is_fictitious,sort_index,is_release,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2):
@@ -140,7 +140,7 @@ class ModuleBaseModel():
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
-        
+
         is_add = False
         old_act_module = None
         now_datetime = SevenHelper.get_now_datetime()
@@ -187,7 +187,7 @@ class ModuleBaseModel():
         act_module.d1 = d1
         act_module.d2 = d2
         act_module.modify_date = now_datetime
-        
+
         if is_add:
             act_module.create_date = now_datetime
             act_module.id = act_module_model.add_entity(act_module)
@@ -200,7 +200,7 @@ class ModuleBaseModel():
         invoke_result_data.data = result
         self._delete_act_module_dependency_key(act_id,act_module.id)
         return invoke_result_data
-        
+
     def update_act_module_status(self,app_id,module_id,is_del):
         """
         :description: 删除或者还原活动模块
@@ -223,7 +223,7 @@ class ModuleBaseModel():
         invoke_result_data.success = act_module_model.update_table("is_del=%s,is_release=%s,release_date=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, module_id])
         self._delete_act_module_dependency_key(act_module_dict["act_id"],module_id)
         return invoke_result_data
-    
+
     def release_act_module(self,app_id,module_id,is_release):
         """
         :description: 活动模块上下架
@@ -244,7 +244,7 @@ class ModuleBaseModel():
         invoke_result_data.success = act_module_model.update_table("release_date=%s,is_release=%s", "id=%s", [SevenHelper.get_now_datetime(), is_release, module_id])
         self._delete_act_module_dependency_key(act_module_dict["act_id"],module_id)
         return invoke_result_data
-    
+
     def update_act_module_price(self,app_id,act_id,prize_gear_id):
         """
         :description: 更新活动模块价格
@@ -266,5 +266,3 @@ class ModuleBaseModel():
         invoke_result_data.success = act_module_model.update_table("price=%s", "act_id=%s and price_gears_id=%s", params=[price_gear_dict["price"], act_id, prize_gear_id])
         self._delete_act_module_dependency_key(act_id,0)
         return invoke_result_data
-    
-
