@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2022-02-25 10:07:12
+@LastEditTime: 2022-02-25 14:17:05
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -32,37 +32,35 @@ class OrderBaseModel(FrameBaseModel):
         self.logging_link_info = logging_info
         super(OrderBaseModel,self).__init__(context)
 
-    def _delete_prize_order_dependency_key(self, act_id, user_id):
+    def _delete_prize_order_dependency_key(self, act_id, user_id, delay_delete_time=0.1):
         """
         :description: 删除订单依赖建
         :param act_id: 活动标识
+        :param user_id: 用户标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        try:
-            dependency_key = f"prize_order_list:actid_{act_id}"
-            if user_id:
-                dependency_key += f"_userid_{user_id}"
-            redis_init = SevenHelper.redis_init()
-            redis_init.delete(dependency_key)
-        except Exception as ex:
-            pass
+        dependency_key = f"prize_order_list:actid_{act_id}"
+        if user_id:
+            dependency_key += f"_userid_{user_id}"
+        PrizeOrderModel().delete_dependency_key(dependency_key, delay_delete_time)
+        
 
-    def _delete_prize_roster_dependency_key(self, act_id, user_id):
+    def _delete_prize_roster_dependency_key(self, act_id, user_id, delay_delete_time=0.1):
         """
         :description: 删除中奖记录依赖建
         :param act_id: 活动标识
+        :param user_id: 用户标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        try:
-            dependency_key = f"prize_roster_list:actid_{act_id}"
-            if user_id:
-                dependency_key += f"_userid_{user_id}"
-            redis_init = SevenHelper.redis_init()
-            redis_init.delete(dependency_key)
-        except Exception as ex:
-            pass
+        dependency_key = f"prize_roster_list:actid_{act_id}"
+        if user_id:
+            dependency_key += f"_userid_{user_id}"
+        PrizeRosterModel().delete_dependency_key(dependency_key, delay_delete_time)
+
 
     def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[], prize_roster_sub_table=None):
         """
