@@ -6,7 +6,7 @@
 @LastEditors: HuangJianYi
 @Description: 
 """
-
+from emoji import unicode_codes
 from seven_cloudapp_frame.libs.customize.cryptography_helper import CryptographyHelper
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.top_base_model import *
@@ -807,6 +807,16 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
+        is_contain_emoji = False
+        for i, item in enumerate(real_name):
+            if item in unicode_codes.UNICODE_EMOJI["en"]:
+                is_contain_emoji = True
+                break
+        if is_contain_emoji == True:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "收货人不能包含表情包"
+            return invoke_result_data
         user_info_dict = self.get_user_info_dict(app_id, act_id, user_id, open_id)
         if not user_info_dict:
             invoke_result_data.success = False
