@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2022-02-18 14:12:41
+@LastEditTime: 2022-03-08 17:34:29
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -24,12 +24,14 @@ def seven_cloudapp_frame_route():
         (r"/client/check_is_member", user.CheckIsMemberHandler),  #校验是否是店铺会员
         (r"/client/apply_black_unbind", user.ApplyBlackUnbindHandler),  #申请黑名单解封
         (r"/client/get_unbind_apply", user.GetUnbindApplyHandler),  #获取黑名单解封申请记录
+        (r"/client/user_asset_list", user.GetUserAssetHandler),  #获取单条用户资产
         (r"/client/user_asset_list", user.UserAssetListHandler),  #用户资产列表
         (r"/client/asset_log_list", user.AssetLogListHandler),  #用户资产流水列表
         (r"/client/get_join_member_url", user.GetJoinMemberUrlHandler),  #加入会员地址
         (r"/client/get_coupon_prize", user.GetCouponPrizeHandler),  #领取淘宝优惠券
         (r"/client/user_address_list", user.UserAddressListHandler),  #收货地址列表
         (r"/client/save_user_address", user.SaveUserAddressHandler),  #保存收货地址
+        (r"/client/get_crm_integral", user.GetCrmIntegralHandler),  #获取淘宝店铺积分
         (r"/client/theme_info", theme.ThemeInfoHandler),  #主题信息
         (r"/client/save_theme", theme.SaveThemeHandler),  #保存主题信息，由前端通过工具进行保存
         (r"/client/save_skin", theme.SaveSkinHandler),  #保存皮肤信息，由前端通过工具进行保存
